# Edit this configuration file to define what should be installed on
# your system.  Help is available in the configuration.nix(5) man page
# and in the NixOS manual (accessible by running ‘nixos-help’).

{ config, pkgs, ... }:

{
  imports =
    [
        ../../modules/system.nix
        ../../modules/nix-settings.nix
        ../../modules/vpn.nix
        ../../modules/fonts.nix
        ../../modules/firewall.nix
        ../../modules/localisation.nix
        ../../modules/openssh.nix
        ../../modules/pipewire.nix
        ../../modules/podman.nix
        ../../modules/services.nix
        ../../modules/regreet/regreet.nix
        ../../modules/plymouth.nix
        ../../modules/file_managers/spacefm.nix

# Include the results of the hardware scan.
        ./hardware-configuration.nix
    ];

  # Bootloader.
  boot.loader = {
    grub = {
        enable = true;
        device = "/dev/sda";
    };
    #efi = {
    #  canTouchEfiVariables = true;
    #  efiSysMountPoint = "/boot/efi"; # ← use the same mount point here.
    #};
    #systemd-boot.enable = true;
  };

  networking.hostName = "nix"; # Define your hostname.
  # networking.wireless.enable = true;  # Enables wireless support via wpa_supplicant.

  # Configure network proxy if necessary
  # networking.proxy.default = "http://user:password@proxy:port/";
  # networking.proxy.noProxy = "127.0.0.1,localhost,internal.domain";

  # Enable networking
  networking.networkmanager.enable = true;
  networking.defaultGateway = "192.168.2.1";
  networking.useDHCP = false;
  networking.dhcpcd.enable = false;
  networking.nameservers = [
	"1.1.1.1"
	"1.0.0.1"
	"8.8.8.8"
	"8.8.4.4"
  ];

  # for Nvidia GPU
  #services.xserver.videoDrivers = ["nvidia"];
  hardware.opengl.enable = true;
  #hardware.nvidia = {
  #  package = config.boot.kernelPackages.nvidiaPackages.stable;
  #  modesetting.enable = true;
  #};

  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It‘s perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "25.05"; # Did you read the comment?

}


